==> gax-0.8.1-sources.jar: com/google/api/gax/grpc/PagedCallable.java <==
/*
 * Copyright 2016, Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.google.api.gax.grpc;

import com.google.api.gax.core.ApiFuture;
import com.google.api.gax.core.internal.ListenableFutureToApiFuture;
import com.google.common.base.Preconditions;
import com.google.common.util.concurrent.Futures;

/**
 * Implements the paged functionality used in {@link UnaryCallable}.
 *
 * <p>
 * Package-private for internal use.
 */
class PagedCallable<RequestT, ResponseT, PagedListResponseT>
    implements FutureCallable<RequestT, PagedListResponseT> {
  private final FutureCallable<RequestT, ResponseT> callable;
  private final PagedListResponseFactory<RequestT, ResponseT, PagedListResponseT>
      pagedListResponseFactory;

  PagedCallable(
      FutureCallable<RequestT, ResponseT> callable,
      PagedListResponseFactory<RequestT, ResponseT, PagedListResponseT> pagedListResponseFactory) {
    this.callable = Preconditions.checkNotNull(callable);
    this.pagedListResponseFactory = pagedListResponseFactory;
  }

  @Override
  public String toString() {
    return String.format("paged(%s)", callable);
  }

  @Override
  public ApiFuture<PagedListResponseT> futureCall(RequestT request, CallContext context) {
    PagedListResponseT pagedListResponse =
        pagedListResponseFactory.createPagedListResponse(
            UnaryCallable.create(callable), request, context);
    return new ListenableFutureToApiFuture<>(Futures.immediateFuture(pagedListResponse));
  }
}

==> gax-0.9.0-sources.jar: com/google/api/gax/grpc/PagedCallable.java <==
/*
 * Copyright 2016, Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.google.api.gax.grpc;

import com.google.api.gax.core.ApiFuture;
import com.google.api.gax.core.internal.ListenableFutureToApiFuture;
import com.google.common.base.Preconditions;
import com.google.common.util.concurrent.Futures;

/**
 * Implements the paged functionality used in {@link UnaryCallable}.
 *
 * <p>
 * Package-private for internal use.
 */
class PagedCallable<RequestT, ResponseT, PagedListResponseT>
    implements FutureCallable<RequestT, PagedListResponseT> {
  private final FutureCallable<RequestT, ResponseT> callable;
  private final PagedListResponseFactory<RequestT, ResponseT, PagedListResponseT>
      pagedListResponseFactory;

  PagedCallable(
      FutureCallable<RequestT, ResponseT> callable,
      PagedListResponseFactory<RequestT, ResponseT, PagedListResponseT> pagedListResponseFactory) {
    this.callable = Preconditions.checkNotNull(callable);
    this.pagedListResponseFactory = pagedListResponseFactory;
  }

  @Override
  public String toString() {
    return String.format("paged(%s)", callable);
  }

  @Override
  public ApiFuture<PagedListResponseT> futureCall(RequestT request, CallContext context) {
    ApiFuture<ResponseT> futureResponse = callable.futureCall(request, context);
    return pagedListResponseFactory.getFuturePagedResponse(
        UnaryCallable.create(callable), request, context, futureResponse);
  }
}
